Nom based line parser for the exposition format specified at Prometheus documentation
Structs
- Comment
- Represents parsed
typeorhelpcomments for eachmetric. See examples at try_read_comment for more details. - Label
List - List of labels for a SampleData. See examples at try_read_sample for more details.
- Sample
Data - Represents a parsed metric sample. See examples at try_read_sample for more details.
Enums
- Comment
Type - If it is a
typeorhelpcomment. More details: comments, help text, and type information.
Functions
- try_
read_ comment - Tries to parse a
&strline as a comment and returnsCommentif it succeeds. - try_
read_ sample - Tries to parse a
&strline as a sample and returnsSampleDatacontaing the metric name, labels and value if it succeeds.